@@ -1,5 +1,21 @@
 ljrk <- function(k,y,n,tm,X=NULL,ofst=0)
 {
+ if (sum(duplicated(tm))>0){
+  cat("Error: duplicated observation times\n")  
+ }
+ else{
+  if ((is.null(X)==FALSE)&&(is.matrix(X)==FALSE))
+   X=as.matrix(X)
+  if (is.unsorted(tm)==TRUE){
+   o=order(tm)
+   y=y[o]
+   n=n[o]
+   tm=tm[o]
+   if (is.null(X)==FALSE)
+    X=as.matrix(X[o,])
+   if ((length(ofst)>1)||(ofst[1]!=0))
+    ofst=ofst[o]
+  }
   N=length(y)
   m=ncol(X)
   or.ofst=ofst
@@ -57,4 +73,5 @@ ljrk <- function(k,y,n,tm,X=NULL,ofst=0)
   ret2=out$tau
   names(ret2)=j.labels
   return(list(Coef=ret1,Joinpoints=ret2,wlik=out$ans))
+ }
 }
